@@ -8,9 +8,9 @@ import click
 import yaml
 from junitparser import TestCase, TestSuite, JUnitXml, Skipped, Error
 
-import api
-import schema
-import term
+from . import api
+from . import schema
+from . import term
 
 pipeline_running_states = ['running', 'waiting_for_resource', 'pending']
 
